@@ -12,37 +12,14 @@ package Clustericious::Config::Plugin;
 
 use Hash::Merge qw/merge/;
 use Data::Dumper;
-use Clustericious::Config::Plugin::Conf;
-
 use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 our @mergeStack;
 our @EXPORT = qw( extends_config get_password conf );
 
-=item conf
-
-Returns a mini configuration object which can be
-used to set values to be the same as keys elsewhere
-in the configuration.
-
-example :
-
- ---
- foo : bar
- alsofoo : <%= conf->foo %>
- one :
-   two : three
- another : <%= conf->one->two %>
-
-=cut
-
-sub conf {
-    return Clustericious::Config::Plugin::Conf->new();
-}
-
 =item extends_config
 
 Extend the config using another config file.
